/*
 *  ParamNames  -- A collection of constants used by the AeroLS program.
 *
 *  Copyright (C) 2002-2015, Joseph A. Huwaldt
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *  Or visit:  http://www.gnu.org/licenses/gpl.html
 */

import javax.measure.quantity.Area;
import javax.measure.unit.NonSI;
import javax.measure.unit.SI;
import javax.measure.unit.Unit;

/**
 * An interface that defines constants that stand in for the names of the
 * parameters used in this program. Also contains lists of the units used in
 * this program.
 * 
 * <p> Modified by: Joseph A. Huwaldt </p>
 * 
 * @author Joseph A. Huwaldt,  Date: May 29, 2002
 * @version June 23, 2015
 */
public interface ParamNames {

    public static final String SREF = "Sref";
    public static final String BREF = "bref";
    public static final String CREF = "cref";
    public static final String XMRC = "Xmrc";
    public static final String YMRC = "Ymrc";
    public static final String ZMRC = "Zmrc";

    public static final String SSEG = "area";
    public static final String BSEG = "span";
    public static final String ARSEG = "AR";
    public static final String CRSEG = "Cr";
    public static final String CTSEG = "Ct";
    public static final String TAPER_SEG = "taper";
    public static final String MAC_SEG = "MAC";
    public static final String SWEEPLE_SEG = "Sweep LE";
    public static final String SWEEPTE_SEG = "Sweep TE";
    public static final String SWEEPC4_SEG = "Sweep 1/4c";
    public static final String GAMSEG = "dihedral";
    public static final String XRLE = "Xrle";
    public static final String YRLE = "Yrle";
    public static final String ZRLE = "Zrle";
    public static final String XTLE = "Xtle";
    public static final String YTLE = "Ytle";
    public static final String ZTLE = "Ztle";
    public static final String I_ROOT = "ir";
    public static final String I_TIP = "it";
    public static final String TWIST = "twist";

    public static final String ROWS = "Chordwise Panels";
    public static final String COLUMNS = "Spanwise Panels";
    public static final String CP = "C.P.";

    //  Define lists of units used in this program.
    public static final Unit[] AREA_UNITS = {
        NonSI.SQUARE_FOOT,
        NonSI.SQUARE_INCH,
        SI.SQUARE_METRE,
        SI.CENTIMETER.times(SI.CENTIMETER).asType(Area.class)};

    public static final Unit[] LENGTH_UNITS = {
        NonSI.FOOT,
        NonSI.INCH,
        SI.METER,
        SI.CENTIMETER};
    public static final Unit[] ANGULAR_UNITS = {NonSI.DEGREE_ANGLE, SI.RADIAN};

}
