/*
 *   AutoParamInputs - A container of all the possible inputs to an AutoParam object.
 *
 *   Copyright (C) 2000-2016, by Joseph A. Huwaldt.
 *   All rights reserved.
 *   
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) any later version.
 *   
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *  Or visit:  http://www.gnu.org/licenses/lgpl.html
 */
package jahuwaldt.js.ParamTools;

import java.net.URL;
import java.text.NumberFormat;
import javax.measure.quantity.Quantity;
import javax.measure.unit.Unit;

/**
 * Serves as a collection of inputs for creating a new AutoParam object.
 * 
 * <p> Modified by: Joseph A. Huwaldt </p>
 * 
 * @author Joseph A. Huwaldt, Date: July 3, 2000
 * @version March 28, 2016
 * @param <Q> The Quantity (unit type) for this parameter.
 */
public class AutoParamInputs<Q extends Quantity> {

    /**
     * The parameter database this parameter should use to lookup other parameters. May
     * not be null.
     */
    public ParamDatabase theDatabase;

    /**
     * The label to be attached to this parameter.
     */
    public String label;

    /**
     * The description of this parameter.
     */
    public String desc;

    /**
     * URL to an image to optionally use in place of the text label string.
     */
    public URL symbolURL;

    /**
     * The current units associated with this parameter.
     */
    public Unit<Q> theUnits;

    /**
     * A list of available units that this parameter can use.
     */
    public Unit<Q>[] availUnits;

    /**
     * Reference to a ParamMethod object to calculate this parameter with.
     */
    public ParamMethod<Q> theMethod;

    /**
     * An array of ParamMethod objects that can be used to calculate this parameter. If a
     * method list is supplied, "theMethod" is ignored.
     */
    public ParamMethod<Q>[] methodLst;

    /**
     * The ParamVerifier object to use to verify the validity of this parameter.
     */
    public ParamVerifier verifierMethod;

    /**
     * The number format to use when displaying this parameter. Also used in the
     * ParamInput box for parsing inputs for this parameter.
     */
    public NumberFormat numFormat;

}
