/*
*   ARfn_b_S - Method for calculating AR based on b, and S.
*
*   Copyright (C) 1999-2009 by Joseph A. Huwaldt
*   All rights reserved.
*   
*   This library is free software; you can redistribute it and/or
*   modify it under the terms of the GNU Lesser General Public
*   License as published by the Free Software Foundation; either
*   version 2.1 of the License, or (at your option) any later version.
*   
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*   Library General Public License for more details.
*
*  You should have received a copy of the GNU Lesser General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*  Or visit:  http://www.gnu.org/licenses/lgpl.html
**/
package jahuwaldt.js.pmethods.winggeom;

import javax.measure.quantity.Dimensionless;
import javax.measure.unit.SI;

import jahuwaldt.js.param.Parameter;
import jahuwaldt.js.ParamTools.*;


/**
*  <p>  Calculates planform wing aspect ratio based on planform
*       span and area.
*  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  February 6, 1999
*  @version  April 25, 2009
**/
public class ARfn_b_S extends AbstractParamMethod<Dimensionless> {

	/**
	*  Constructor for this method.
	*
	*  @param  b  Label for the "span" parameter.
	*  @param  S  Label for the "planform area" parameter.
	**/
	public  ARfn_b_S( String b, String S ) {
		_inputLabels = new String [ 2 ];
		_inputLabels[0] = b;
		_inputLabels[1] = S;
	}

	/**
	*  Calculates planform wing aspect ratio based on planform
	*  wing span and area.
	*  Method:  AR = b^2/S
	*
	*  @param   inputs  Array of input parameters.
	*                   [0=planform span (b), 1=planform area (S)].
	*  @return  Planform aspect ratio (AR).
	**/
	public Parameter<Dimensionless> calc( Parameter[] inputs ) {
		Parameter b = inputs[0];
		Parameter S = inputs[1];
		Parameter AR = b.times(b).divide(S);	//	AR = b * b / S;
		return AR.asType(Dimensionless.class);
	}


}


