/*
*   Sfn_b_AR - Method for calculating S as a function of b and AR.
*
*   Copyright (C) 1998-2009 by Joseph A. Huwaldt
*   All rights reserved.
*   
*   This library is free software; you can redistribute it and/or
*   modify it under the terms of the GNU Lesser General Public
*   License as published by the Free Software Foundation; either
*   version 2.1 of the License, or (at your option) any later version.
*   
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*   Library General Public License for more details.
*
*  You should have received a copy of the GNU Lesser General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*  Or visit:  http://www.gnu.org/licenses/lgpl.html
**/
package jahuwaldt.js.pmethods.winggeom;


import javax.measure.quantity.Area;
import javax.measure.unit.SI;

import jahuwaldt.js.param.Parameter;
import jahuwaldt.js.ParamTools.*;


/**
*  <p>  Calculates planform wing area based on planform span and
*       aspect ratio.
*  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  February 6, 1999
*  @version  April 26, 2009
**/
public class Sfn_b_AR extends AbstractParamMethod<Area> {

	/**
	*  Constructor for this method.
	*
	*  @param  b  Label for the "span" parameter.
	*  @param  AR Label for the "aspec ratio" parameter.
	**/
	public Sfn_b_AR( String b, String AR ) {
		_inputLabels = new String [ 2 ];
		_inputLabels[0] = b;
		_inputLabels[1] = AR;
	}

	/**
	*  Calculates planform wing area based on planform wing
	*  span and aspect ratio.
	*  Method:  S = b^2/AR
	*
	*  @param  inputs  Array of input parameters.
	*                  [0=planform span (b), 1=planform aspect ratio (AR)].
	*  @return  Planform wing area (S) in square units of input wing span.
	**/
	public Parameter<Area> calc( Parameter[] inputs ) {
		Parameter b = inputs[0];
		Parameter AR = inputs[1];
		Parameter S = b.times(b).divide(AR);		//	S = b * b / AR;
		return S.asType(Area.class);
	}


}


