/*
*   bfn_S_AR - Method for calculating b as a function of S and AR.
*
*   Copyright (C) 1999-2009 by Joseph A. Huwaldt
*   All rights reserved.
*   
*   This library is free software; you can redistribute it and/or
*   modify it under the terms of the GNU Lesser General Public
*   License as published by the Free Software Foundation; either
*   version 2.1 of the License, or (at your option) any later version.
*   
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*   Library General Public License for more details.
*
*  You should have received a copy of the GNU Lesser General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*  Or visit:  http://www.gnu.org/licenses/lgpl.html
**/
package jahuwaldt.js.pmethods.winggeom;


import javax.measure.quantity.Length;
import javax.measure.unit.SI;

import jahuwaldt.js.param.Parameter;
import jahuwaldt.js.ParamTools.*;


/**
*  <p>  Calculates planform wing span based on planform area and
*       aspect ratio.
*  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt   </p>
*
*  @author   Joseph A. Huwaldt   Date:  February 6, 1999
*  @version  April 26, 2009
**/
public class bfn_S_AR extends AbstractParamMethod<Length> {

	/**
	*  Constructor for this method.
	*
	*  @param  S   Label for the "planform area" parameter.
	*  @param  AR  Label for the "aspec ratio" parameter.
	**/
	public bfn_S_AR( String S, String AR ) {
		_inputLabels = new String [ 2 ];
		_inputLabels[0] = S;
		_inputLabels[1] = AR;
	}

	/**
	*  Calculates planform wing span based on planform wing area
	*  and aspect ratio.
	*  Method:  b = sqrt( S*AR )
	*
	*  @param  inputs  Array of input parameters.
	*                  [0=planform area (S), 1=planform aspect ratio(AR)].
	*  @return Planform wing span (b) in units that are the square
	*          root of the area units.
	**/
	public Parameter<Length> calc( Parameter[] inputs ) {
		Parameter S = inputs[0];
		Parameter AR = inputs[1];
		Parameter b = S.times(AR).sqrt();	//	b = sqrt(S*AR)
		return b.asType(Length.class);
	}


}


