/*
*   HelpSystem - Interface that provides help information to a program.
*
*   Copyright (C) 1999-2004 by Joseph A. Huwaldt
*   All rights reserved.
*   
*   This library is free software; you can redistribute it and/or
*   modify it under the terms of the GNU Lesser General Public
*   License as published by the Free Software Foundation; either
*   version 2 of the License, or (at your option) any later version.
*   
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*   Library General Public License for more details.
*
*   You should have received a copy of the GNU Lesser General Public License
*   along with this program; if not, write to the Free Software
*   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*   Or visit:  http://www.gnu.org/licenses/lgpl.html
**/
package jahuwaldt.util;



/**
*  Interface for classes that provide help information.
*  Help may be provided in many ways; this interface allows
*  classes to implement help without knowing the particulars
*  of the implementation.
*
*  <p>  Modified by:  Joseph A. Huwaldt    </p>
*
*  @author  Joseph A. Huwaldt   Date: October 7, 1999
*  @version November 6, 2004
**/
public interface HelpSystem {

	/**
	*  Help information contained in this help object should be shown
	*  when this method is called.
	**/
	public void showHelp();

	/**
	*  Returns true if help information is available, false if it
	*  is not.
	*
	*  @return Returns true if help information is available, false otherwise.
	**/
	public boolean helpAvailable();

}


